@@ -18,13 +18,13 @@ finally:
 
 from .io import read_data  # noqa: E402
 from .preprocess import preprocess, filter_dataframe, replace_parts_animal_movement, resample_systematic, \
-    resample_random,split_trajectories,convert_measueres, interpolate, print_missing, print_duplicate, plot_missing_values  # noqa:
+    resample_random,split_trajectories,convert_measueres, interpolate, print_missing, print_duplicate, plot_missing_values, normalize  # noqa:
 # E402
 from .feature_extraction import extract_features, euclidean_dist  # noqa: E402
 from .feature_extraction import ts_feature, ts_all_features, explore_features_geospatial, centroid_medoid_computation, \
     outlier_detection, group_movement
-from .clustering import dtw_matrix, ts_cluster, get_heading_difference, compute_polarization, get_spatial_objects, compute_centroid_direction
+from .clustering import dtw_matrix, get_heading_difference, compute_polarization, get_spatial_objects, compute_centroid_direction, clustering, clustering_with_splits
 # noqa: E402
-from .plot import plot_animal, plot_pace, plot_movement  # noqa: E402
+from .plot import plot_animal, plot_pace, plot_movement, animate_movement  # noqa: E402
 
 from .network import network_time_graphlist
\ No newline at end of file
